Contributing
============

We welcome contributions!

Start here:

- https://github.com/skygazer42/pyimgano/blob/main/CONTRIBUTING.md
- https://github.com/skygazer42/pyimgano/blob/main/CODE_OF_CONDUCT.md
- https://github.com/skygazer42/pyimgano/blob/main/SECURITY.md

Docs
----

- CLI reference: https://github.com/skygazer42/pyimgano/blob/main/docs/CLI_REFERENCE.md
- Publishing: https://github.com/skygazer42/pyimgano/blob/main/docs/PUBLISHING.md
- First-tier roadmap: https://github.com/skygazer42/pyimgano/blob/main/docs/FIRST_TIER_ROADMAP.md
- Benchmark reproducibility issues: https://github.com/skygazer42/pyimgano/issues/new/choose
